@@ -5,7 +5,7 @@ class User(object):
         self.name = name
         self.connections = []
         self.channels = []
-        
+        self._temp_cookie = ""
     def serialize(self):
         return {
             'channels': [ chan.name for chan in self.channels ],
@@ -25,10 +25,8 @@ class User(object):
             conn.send_frame('SUBSCRIBE', frame)
             
     def remove_connection(self, conn):
-        print 'remove conn on user', self.name
         self.connections.remove(conn)
         if not self.connections:
-            print 'no more connections...'
             # each call to user_disconnected might result in an immediate call
             # to self.channel_unsubscribed, thus modifying self.channels and
             # messing up our loop. So we loop over a copy of self.channels...
@@ -36,6 +34,8 @@ class User(object):
             for channel in self.channels[:]:
                 channel.user_disconnected(self)
 #            print 'tell server to remove user...'
+            # so the disconnect callback has a cookie
+            self._temp_cookie = conn.get_cookie()
             self.server.remove_user(self.name)
             
     def channel_subscribed(self, channel):
@@ -55,6 +55,7 @@ class User(object):
     def get_cookie(self, conn=None):
         if conn:
             return conn.get_cookie()
-        return ""
+        
+        return self._temp_cookie or ""
         
     
\ No newline at end of file
